// Copyright  2007 Prodige Software Corporation. All rights reserved.
using System;
using System.ComponentModel;
using System.ComponentModel.Design;
using Prodige.Drawing;
using Prodige.Drawing.Styles;

namespace ComplexAnchoring
{
	/// <summary>
	/// A transparent (translucent) button class that can be reused as a user interface
	/// component. This button has three visual states: normal, mouse hover, and mouse down.
	/// </summary>
	public class TransparentButton : Picture
	{
		private Prodige.Drawing.Rectangle background;
		private Prodige.Drawing.Rectangle highlight;
		private Prodige.Drawing.Rectangle shine;
	
		public TransparentButton()
		{
			InitializeComponent();	// required by the designer
		}

		/// <summary>
		/// The text to display in this button.
		/// </summary>
        [DefaultValue("Click Me")]
		[Description("Text to display in this button.")]
		public string Text
		{
			get { return background.Text; }
			set { background.Text = value; }
		}

		protected override bool SetBoundsCore(FRectangle bounds, BoundsChanges changes)
		{
			// a custom resizing algorithm, to change size of child objects, instead
			// of scaling
			if (bounds == background.Bounds)
				return false;
			float limit = background.CornerRadius * 2;
			if (bounds.Width < limit)
				bounds.Width = limit;
			if (bounds.Height < limit)
				bounds.Height = limit;

			Vector highlightOffset = highlight.Location - background.Location;
			Vector shineOffset = shine.Location - background.Location;
			float widthChange = bounds.Width - background.Width;
			background.Bounds = bounds;
			highlight.Location = background.Location  + highlightOffset;
			highlight.Width += widthChange;
			shine.Location = background.Location + shineOffset;
			shine.Width += widthChange;
			return true;
		}

		// Mouse event function are overriden to provide visual
		// state changes.

		public override void OnMouseEnter(InputEventArgs args)
		{
			background.Style = "HoverBackground";
			base.OnMouseEnter(args);
		}

		public override void OnMouseLeave(InputEventArgs args)
		{
			background.Style = "Background";
			base.OnMouseLeave(args);
		}
		
		public override void OnMouseDown(ElementMouseEventArgs args)
		{
			background.Style = "DownBackground";
			base.OnMouseDown(args);
		}

		public override void OnMouseUp(ElementMouseEventArgs args)
		{
			background.Style = "HoverBackground";
			base.OnMouseUp(args);
		}

		#region Designer generated code
		/// <summary> 
		/// Required for designer support - do not modify with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			Prodige.Drawing.Styles.LinearGradientFill linearGradientFill1 = new Prodige.Drawing.Styles.LinearGradientFill();
			Prodige.Drawing.Styles.LinearGradientFill linearGradientFill2 = new Prodige.Drawing.Styles.LinearGradientFill(0F, 0F, 1F, 0.9F, Prodige.Drawing.Styles.FillCoordinateType.Relative, Prodige.Drawing.Styles.GradientType.TwoColorBell);
			Prodige.Drawing.Styles.LinearGradientFill linearGradientFill3 = new Prodige.Drawing.Styles.LinearGradientFill(0F, 0.1F, 1F, 0.9F, Prodige.Drawing.Styles.FillCoordinateType.Relative, Prodige.Drawing.Styles.GradientType.TwoColor);
			Prodige.Drawing.Styles.LinearGradientFill linearGradientFill4 = new Prodige.Drawing.Styles.LinearGradientFill();
			Prodige.Drawing.Styles.LinearGradientFill linearGradientFill5 = new Prodige.Drawing.Styles.LinearGradientFill(0F, 0.1F, 1F, 0.8F, Prodige.Drawing.Styles.FillCoordinateType.Relative, Prodige.Drawing.Styles.GradientType.TwoColor);
			Prodige.Drawing.Styles.TextAppearance textAppearance1 = new Prodige.Drawing.Styles.TextAppearance(System.Drawing.Color.FromArgb(((int)(((byte)(201)))), ((int)(((byte)(204)))), ((int)(((byte)(245))))));
			this.background = new Prodige.Drawing.Rectangle();
			this.highlight = new Prodige.Drawing.Rectangle();
			this.shine = new Prodige.Drawing.Rectangle();
			((System.ComponentModel.ISupportInitialize)(this)).BeginInit();
			// 
			// background
			// 
			this.background.CornerRadii = new Prodige.Drawing.Radii(20F, 20F);
			this.background.DrawAction = Prodige.Drawing.ShapeDrawAction.Fill;
			this.background.Location = new Prodige.Drawing.Vector(100F, 100F);
			this.background.Size = new Prodige.Drawing.FSize(200F, 100F);
			this.background.Style = "Background";
			this.background.Text = "Click Me";
			// 
			// highlight
			// 
			this.highlight.CornerRadii = new Prodige.Drawing.Radii(20F, 20F);
			this.highlight.DrawAction = Prodige.Drawing.ShapeDrawAction.Fill;
			this.highlight.Location = new Prodige.Drawing.Vector(101F, 101F);
			this.highlight.Size = new Prodige.Drawing.FSize(198F, 41F);
			this.highlight.Style = "Highlight";
			// 
			// shine
			// 
			this.shine.CornerRadii = new Prodige.Drawing.Radii(10F, 10F);
			this.shine.DrawAction = Prodige.Drawing.ShapeDrawAction.Fill;
			this.shine.Location = new Prodige.Drawing.Vector(110F, 105F);
			this.shine.Size = new Prodige.Drawing.FSize(178F, 10F);
			this.shine.Style = "Shine";
			// 
			// TransparentButton
			// 
			this.Elements.AddRange(new Prodige.Drawing.Element[] {
            this.background,
            this.highlight,
            this.shine});
			linearGradientFill1.Angle = 90F;
			linearGradientFill1.EndColor = System.Drawing.Color.FromArgb(((int)(((byte)(84)))), ((int)(((byte)(192)))), ((int)(((byte)(192)))), ((int)(((byte)(255)))));
			linearGradientFill1.EndOpacity = 0.3294118F;
			linearGradientFill1.StartColor = System.Drawing.Color.FromArgb(((int)(((byte)(162)))), ((int)(((byte)(192)))), ((int)(((byte)(192)))), ((int)(((byte)(255)))));
			linearGradientFill1.StartOpacity = 0.6352941F;
			linearGradientFill2.Angle = 90F;
			linearGradientFill2.BlendFocus = 0.05F;
			linearGradientFill2.EndColor = System.Drawing.Color.FromArgb(((int)(((byte)(147)))), ((int)(((byte)(196)))), ((int)(((byte)(196)))), ((int)(((byte)(255)))));
			linearGradientFill2.EndOpacity = 0.5764706F;
			linearGradientFill2.StartOpacity = 0F;
			linearGradientFill3.Angle = 90F;
			linearGradientFill3.EndColor = System.Drawing.Color.FromArgb(((int)(((byte)(0)))), ((int)(((byte)(255)))), ((int)(((byte)(255)))), ((int)(((byte)(255)))));
			linearGradientFill3.EndOpacity = 0F;
			linearGradientFill3.StartColor = System.Drawing.Color.FromArgb(((int)(((byte)(72)))), ((int)(((byte)(255)))), ((int)(((byte)(255)))), ((int)(((byte)(255)))));
			linearGradientFill3.StartOpacity = 0.282353F;
			linearGradientFill4.Angle = 90F;
			linearGradientFill4.EndColor = System.Drawing.Color.FromArgb(((int)(((byte)(171)))), ((int)(((byte)(0)))), ((int)(((byte)(0)))), ((int)(((byte)(255)))));
			linearGradientFill4.EndOpacity = 0.6705883F;
			linearGradientFill4.StartColor = System.Drawing.Color.FromArgb(((int)(((byte)(44)))), ((int)(((byte)(0)))), ((int)(((byte)(0)))), ((int)(((byte)(192)))));
			linearGradientFill4.StartOpacity = 0.172549F;
			linearGradientFill5.Angle = 270F;
			linearGradientFill5.EndColor = System.Drawing.Color.FromArgb(((int)(((byte)(82)))), ((int)(((byte)(128)))), ((int)(((byte)(128)))), ((int)(((byte)(255)))));
			linearGradientFill5.EndOpacity = 0.3215686F;
			linearGradientFill5.StartColor = System.Drawing.Color.FromArgb(((int)(((byte)(181)))), ((int)(((byte)(128)))), ((int)(((byte)(128)))), ((int)(((byte)(255)))));
			linearGradientFill5.StartOpacity = 0.7098039F;
			this.Styles.Add(new Prodige.Drawing.Styles.Style("Background", null, linearGradientFill1, null, null));
			this.Styles.Add(new Prodige.Drawing.Styles.Style("Highlight", null, linearGradientFill2, null, null));
			this.Styles.Add(new Prodige.Drawing.Styles.Style("Shine", null, linearGradientFill3, null, null));
			this.Styles.Add(new Prodige.Drawing.Styles.Style("HoverBackground", null, linearGradientFill4, null, null));
			this.Styles.Add(new Prodige.Drawing.Styles.Style("DownBackground", null, linearGradientFill5, null, null));
			textAppearance1.RenderingHint = System.Drawing.Text.TextRenderingHint.AntiAliasGridFit;
			textAppearance1.Size = 27F;
			textAppearance1.SizeUnit = System.Drawing.GraphicsUnit.World;
			this.TextAppearance = textAppearance1;
			((System.ComponentModel.ISupportInitialize)(this)).EndInit();

		}
		#endregion
	}
}
