// Copyright  2007 Prodige Software Corporation. All rights reserved.
using System;
using System.ComponentModel;
using System.Windows.Forms;
using Prodige.Drawing;
using Prodige.Drawing.Styles;

namespace ComplexAnchoring
{
	public class TransparentSlider : UIElement
	{
		private Prodige.Drawing.Group knob;
		private Prodige.Drawing.Rectangle grooveBackground;
		private Prodige.Drawing.Rectangle grooveTopShadow;
		private Prodige.Drawing.Rectangle grooveShine;
		private Prodige.Drawing.Rectangle grooveShadow;
		private Prodige.Drawing.Rectangle knobBackground;
		private Prodige.Drawing.Rectangle knobHighlight;
		private Prodige.Drawing.Rectangle knobShine;
		private Prodige.Drawing.Rectangle backRectangle;
		private Prodige.Drawing.Path ticks;
		private Prodige.Drawing.Rectangle grooveBackgroundShine;
		private Prodige.Drawing.Rectangle grooveBackgroundShadow;
		private Prodige.Drawing.Group groove;
		private Prodige.Drawing.Group grooveKnob;

		// the maximum knob movement, as a distance from top or bottom to edge of knob
		private const float knobMargin = 15;
		private const int defaultTickCount = 5;
		private const int defaultMajorTickFrequency = 5;

		private bool sliding;
		private int majorTickFrequency;
		private int tickCount;
	
		public TransparentSlider()
		{
			InitializeComponent();	// required by the designer
			tickCount = defaultTickCount;
			majorTickFrequency = defaultMajorTickFrequency;
		}

		/// <summary>
		/// The number of tick marks on this <see cref="TransparentSlider"/>.
		/// </summary>
		[DefaultValue(defaultTickCount)]
		[Description("The number of tick marks.")]
		[Category("Ticks")]
		public int TickCount
		{
			get { return tickCount; }
			set
			{
				if (tickCount == value)
					return;
				Check.Argument(value > 1, "value", "TickCount cannot be less than 2");
				tickCount = value;
				ComputeTicks();
			}
		}

		/// <summary>
		/// The number of minor ticks between major ticks, minus one.
		/// </summary>
		[DefaultValue(defaultMajorTickFrequency)]
		[Description("The number of minor ticks between major ticks, minus one.")]
		[Category("Ticks")]
		public int MajorTickFrequency
		{
			get { return majorTickFrequency; }
			set
			{
				if (majorTickFrequency == value)
					return;
				Check.Argument(value >= 1, "value", "MajorTickFrequency cannot be less than 1");
				majorTickFrequency = value;
				ComputeTicks();
			}
		}

		private void ComputeTicks()
		{
			PathPointCollection points = ticks.PathPoints;
			float x1 = points[0].X;
			float x2 = points[1].X;
			float height = grooveBackground.Height - 2* knobMargin;
			float top = grooveBackground.Location.Y + knobMargin;
			float minorX1 = x1 + (x2 - x1)/2;
			points.Clear();
			for (int i = 0; i < tickCount; i++)
			{
				float y = top + (i * height)/(tickCount - 1);
				float x;
				if ((tickCount - i) % majorTickFrequency == 0)
					x = x1;
				else
					x = minorX1;
				points.Add(new PathPoint(x, y, PointType.Start));
				points.Add(new PathPoint(x2, y));
			}
		}


		private void TransparentSlider_MouseEnter(object sender, InputEventArgs e)
		{
			knobBackground.Style = "HoverBackground";
			grooveBackground.Style = "HoverGrooveBackground";
			grooveShadow.Style = "HoverGrooveShadow";
		}

		private void TransparentSlider_MouseDown(object sender, ElementMouseEventArgs e)
		{
			knobBackground.Style = "DownBackground";
			if (e.Button == MouseButtons.Left)
			{
				sliding = true;
				Slide(e);
				CaptureMouse();
			}
			System.Diagnostics.Debug.WriteLine("Down, sliding: " + sliding);
		}

		private void TransparentSlider_MouseMove(object sender, ElementMouseEventArgs e)
		{
			if (!sliding)
				return;
			Slide(e);
		}

		private void Slide(ElementMouseEventArgs e)
		{
			float y = PointPageToChild(e.PagePoint).Y;
			FRectangle bounds = Bounds;
			float topLimit = bounds.Top + knobMargin;
			float bottomLimit = bounds.Bottom - knobMargin;
			if (y < topLimit)
				y = topLimit;
			if (y > bottomLimit)
				y = bottomLimit;
			// TODO: Top should be an assignable property in VG.net
			knob.Location = new Vector(knob.Location.X, y - knob.Height/2);
			System.Diagnostics.Debug.WriteLine("Move, y: " + y);
		}

		private void TransparentSlider_MouseLeave(object sender, InputEventArgs e)
		{
			knobBackground.Style = "Background";
			grooveBackground.Style = "GrooveBackground";
			grooveShadow.Style = "GrooveShadow";
			sliding = false;
			ReleaseMouseCapture();
			System.Diagnostics.Debug.WriteLine("Leave");
		}

		private void TransparentSlider_MouseUp(object sender, ElementMouseEventArgs e)
		{
			knobBackground.Style = "HoverBackground";
			sliding = false;
			ReleaseMouseCapture();
			System.Diagnostics.Debug.WriteLine("Up");
		}
		

		#region Designer generated code
		/// <summary> 
		/// Required for designer support - do not modify with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			Prodige.Drawing.Styles.LinearGradientFill linearGradientFill1 = new Prodige.Drawing.Styles.LinearGradientFill();
			Prodige.Drawing.Styles.LinearGradientFill linearGradientFill2 = new Prodige.Drawing.Styles.LinearGradientFill();
			Prodige.Drawing.Styles.LinearGradientFill linearGradientFill3 = new Prodige.Drawing.Styles.LinearGradientFill();
			Prodige.Drawing.Styles.LinearGradientFill linearGradientFill4 = new Prodige.Drawing.Styles.LinearGradientFill(0F, 0F, 1F, 0.9F, Prodige.Drawing.Styles.FillCoordinateType.Relative, Prodige.Drawing.Styles.GradientType.TwoColorBell);
			Prodige.Drawing.Styles.LinearGradientFill linearGradientFill5 = new Prodige.Drawing.Styles.LinearGradientFill(0F, 0.1F, 1F, 0.9F, Prodige.Drawing.Styles.FillCoordinateType.Relative, Prodige.Drawing.Styles.GradientType.TwoColor);
			Prodige.Drawing.Styles.LinearGradientFill linearGradientFill6 = new Prodige.Drawing.Styles.LinearGradientFill(0.4F, 0F, 0.4F, 1F, Prodige.Drawing.Styles.FillCoordinateType.Relative, Prodige.Drawing.Styles.GradientType.TwoColor);
			Prodige.Drawing.Styles.LinearGradientFill linearGradientFill7 = new Prodige.Drawing.Styles.LinearGradientFill();
			Prodige.Drawing.Styles.LinearGradientFill linearGradientFill8 = new Prodige.Drawing.Styles.LinearGradientFill(0F, 0.1F, 1F, 0.8F, Prodige.Drawing.Styles.FillCoordinateType.Relative, Prodige.Drawing.Styles.GradientType.TwoColor);
			Prodige.Drawing.Styles.Stroke stroke1 = new Prodige.Drawing.Styles.Stroke(System.Drawing.Color.FromArgb(((System.Byte)(120)), ((System.Byte)(192)), ((System.Byte)(192)), ((System.Byte)(255))));
			Prodige.Drawing.Styles.LinearGradientFill linearGradientFill9 = new Prodige.Drawing.Styles.LinearGradientFill(0.1F, 0F, 0.88F, 1F, Prodige.Drawing.Styles.FillCoordinateType.Relative, Prodige.Drawing.Styles.GradientType.TwoColor);
			Prodige.Drawing.Styles.LinearGradientFill linearGradientFill10 = new Prodige.Drawing.Styles.LinearGradientFill(0.1F, 0F, 0.7F, 1F, Prodige.Drawing.Styles.FillCoordinateType.Relative, Prodige.Drawing.Styles.GradientType.TwoColor);
			Prodige.Drawing.Styles.LinearGradientFill linearGradientFill11 = new Prodige.Drawing.Styles.LinearGradientFill(0F, 0F, 1F, 0.9F, Prodige.Drawing.Styles.FillCoordinateType.Relative, Prodige.Drawing.Styles.GradientType.TwoColor);
			Prodige.Drawing.Styles.LinearGradientFill linearGradientFill12 = new Prodige.Drawing.Styles.LinearGradientFill(0F, 0F, 1F, 0.9F, Prodige.Drawing.Styles.FillCoordinateType.Relative, Prodige.Drawing.Styles.GradientType.TwoColor);
			Prodige.Drawing.Styles.LinearGradientFill linearGradientFill13 = new Prodige.Drawing.Styles.LinearGradientFill(0.1F, 0F, 0.88F, 1F, Prodige.Drawing.Styles.FillCoordinateType.Relative, Prodige.Drawing.Styles.GradientType.TwoColor);
			Prodige.Drawing.Styles.LinearGradientFill linearGradientFill14 = new Prodige.Drawing.Styles.LinearGradientFill(0.1F, 0F, 0.7F, 1F, Prodige.Drawing.Styles.FillCoordinateType.Relative, Prodige.Drawing.Styles.GradientType.TwoColor);
			Prodige.Drawing.Styles.TextAppearance textAppearance1 = new Prodige.Drawing.Styles.TextAppearance(System.Drawing.Color.FromArgb(((System.Byte)(201)), ((System.Byte)(204)), ((System.Byte)(245))));
			this.knobBackground = new Prodige.Drawing.Rectangle();
			this.knobHighlight = new Prodige.Drawing.Rectangle();
			this.knobShine = new Prodige.Drawing.Rectangle();
			this.knob = new Prodige.Drawing.Group();
			this.grooveBackground = new Prodige.Drawing.Rectangle();
			this.grooveTopShadow = new Prodige.Drawing.Rectangle();
			this.grooveShine = new Prodige.Drawing.Rectangle();
			this.grooveShadow = new Prodige.Drawing.Rectangle();
			this.ticks = new Prodige.Drawing.Path();
			this.backRectangle = new Prodige.Drawing.Rectangle();
			this.grooveBackgroundShine = new Prodige.Drawing.Rectangle();
			this.grooveBackgroundShadow = new Prodige.Drawing.Rectangle();
			this.groove = new Prodige.Drawing.Group();
			this.grooveKnob = new Prodige.Drawing.Group();
			((System.ComponentModel.ISupportInitialize)(this)).BeginInit();
			// 
			// knobBackground
			// 
			this.SetAnchor(this.knobBackground, ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right))));
			this.knobBackground.CornerRadius = 10F;
			this.knobBackground.DrawAction = Prodige.Drawing.ShapeDrawAction.Fill;
			this.knobBackground.Location = new Prodige.Drawing.Vector(13F, 42F);
			this.knobBackground.Size = new Prodige.Drawing.FSize(36F, 16F);
			this.knobBackground.Style = "Background";
			// 
			// knobHighlight
			// 
			this.SetAnchor(this.knobHighlight, ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right))));
			this.knobHighlight.CornerRadius = 10F;
			this.knobHighlight.DrawAction = Prodige.Drawing.ShapeDrawAction.Fill;
			this.knobHighlight.Location = new Prodige.Drawing.Vector(14F, 43F);
			this.knobHighlight.Size = new Prodige.Drawing.FSize(34F, 14F);
			this.knobHighlight.Style = "Highlight";
			// 
			// knobShine
			// 
			this.SetAnchor(this.knobShine, ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right))));
			this.knobShine.CornerRadius = 10F;
			this.knobShine.DrawAction = Prodige.Drawing.ShapeDrawAction.Fill;
			this.knobShine.Location = new Prodige.Drawing.Vector(19F, 45F);
			this.knobShine.Size = new Prodige.Drawing.FSize(24F, 4F);
			this.knobShine.Style = "Shine";
			// 
			// knob
			// 
			this.SetAnchor(this.knob, ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Left | System.Windows.Forms.AnchorStyles.Right))));
			this.knob.Elements.AddRange(new Prodige.Drawing.Element[] {
																		  this.knobBackground,
																		  this.knobHighlight,
																		  this.knobShine});
			// 
			// grooveBackground
			// 
			this.SetAnchor(this.grooveBackground, ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
				| System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right))));
			this.grooveBackground.CornerRadius = 10F;
			this.grooveBackground.DrawAction = Prodige.Drawing.ShapeDrawAction.Fill;
			this.grooveBackground.Location = new Prodige.Drawing.Vector(25F, 0F);
			this.grooveBackground.Size = new Prodige.Drawing.FSize(12F, 100F);
			this.grooveBackground.Style = "GrooveBackground";
			// 
			// grooveTopShadow
			// 
			this.SetAnchor(this.grooveTopShadow, ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right))));
			this.grooveTopShadow.CornerRadius = 10F;
			this.grooveTopShadow.DrawAction = Prodige.Drawing.ShapeDrawAction.Fill;
			this.grooveTopShadow.Location = new Prodige.Drawing.Vector(27F, 2F);
			this.grooveTopShadow.Size = new Prodige.Drawing.FSize(8F, 12F);
			this.grooveTopShadow.Style = "GrooveTopShadow";
			// 
			// grooveShine
			// 
			this.SetAnchor(this.grooveShine, ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right))));
			this.grooveShine.CornerRadius = 10F;
			this.grooveShine.DrawAction = Prodige.Drawing.ShapeDrawAction.Fill;
			this.grooveShine.Location = new Prodige.Drawing.Vector(27F, 85F);
			this.grooveShine.Size = new Prodige.Drawing.FSize(8F, 13F);
			this.grooveShine.Style = "GrooveShine";
			// 
			// grooveShadow
			// 
			this.SetAnchor(this.grooveShadow, ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
				| System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right))));
			this.grooveShadow.CornerRadius = 10F;
			this.grooveShadow.DrawAction = Prodige.Drawing.ShapeDrawAction.Fill;
			this.grooveShadow.Location = new Prodige.Drawing.Vector(27F, 2F);
			this.grooveShadow.Size = new Prodige.Drawing.FSize(8F, 96F);
			this.grooveShadow.Style = "GrooveShadow";
			// 
			// ticks
			// 
			this.SetAnchor(this.ticks, ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
				| System.Windows.Forms.AnchorStyles.Left))));
			this.ticks.DrawAction = Prodige.Drawing.ShapeDrawAction.Edge;
			this.ticks.PathPoints.AddRange(new Prodige.Drawing.PathPoint[] {
																			   new Prodige.Drawing.PathPoint(0F, 86F, Prodige.Drawing.PointType.Start),
																			   new Prodige.Drawing.PathPoint(15F, 86F),
																			   new Prodige.Drawing.PathPoint(0F, 68F, Prodige.Drawing.PointType.Start),
																			   new Prodige.Drawing.PathPoint(15F, 68F),
																			   new Prodige.Drawing.PathPoint(0F, 50F, Prodige.Drawing.PointType.Start),
																			   new Prodige.Drawing.PathPoint(15F, 50F),
																			   new Prodige.Drawing.PathPoint(0F, 32F, Prodige.Drawing.PointType.Start),
																			   new Prodige.Drawing.PathPoint(15F, 32F),
																			   new Prodige.Drawing.PathPoint(0F, 15F, Prodige.Drawing.PointType.Start),
																			   new Prodige.Drawing.PathPoint(15F, 15F)});
			this.ticks.Style = "Tick";
			// 
			// backRectangle
			// 
			this.SetAnchor(this.backRectangle, ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
				| System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right))));
			this.backRectangle.DrawAction = Prodige.Drawing.ShapeDrawAction.Fill;
			this.backRectangle.Fill = new Prodige.Drawing.Styles.SolidFill(0F);
			this.backRectangle.Location = new Prodige.Drawing.Vector(0F, 0F);
			this.backRectangle.Size = new Prodige.Drawing.FSize(60F, 100F);
			// 
			// grooveBackgroundShine
			// 
			this.SetAnchor(this.grooveBackgroundShine, ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right))));
			this.grooveBackgroundShine.CornerRadius = 10F;
			this.grooveBackgroundShine.DrawAction = Prodige.Drawing.ShapeDrawAction.Fill;
			linearGradientFill1.Angle = 45F;
			this.grooveBackgroundShine.Fill = linearGradientFill1;
			this.grooveBackgroundShine.Location = new Prodige.Drawing.Vector(25F, 0F);
			this.grooveBackgroundShine.Size = new Prodige.Drawing.FSize(12F, 12F);
			this.grooveBackgroundShine.Style = "GrooveShine";
			// 
			// grooveBackgroundShadow
			// 
			this.SetAnchor(this.grooveBackgroundShadow, ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right))));
			this.grooveBackgroundShadow.CornerRadius = 10F;
			this.grooveBackgroundShadow.DrawAction = Prodige.Drawing.ShapeDrawAction.Fill;
			linearGradientFill2.Angle = 225F;
			linearGradientFill2.BlendFactors.AddRange(new Prodige.Drawing.Styles.BlendFactor[] {
																								   new Prodige.Drawing.Styles.BlendFactor(0F, 0F),
																								   new Prodige.Drawing.Styles.BlendFactor(0.5F, 1F),
																								   new Prodige.Drawing.Styles.BlendFactor(1F, 1F)});
			linearGradientFill2.EndOpacity = 0F;
			linearGradientFill2.StartColor = System.Drawing.Color.FromArgb(((System.Byte)(76)), ((System.Byte)(0)), ((System.Byte)(0)), ((System.Byte)(0)));
			linearGradientFill2.StartOpacity = 0.2980392F;
			this.grooveBackgroundShadow.Fill = linearGradientFill2;
			this.grooveBackgroundShadow.Location = new Prodige.Drawing.Vector(25F, 88F);
			this.grooveBackgroundShadow.Size = new Prodige.Drawing.FSize(12F, 12F);
			// 
			// groove
			// 
			this.SetAnchor(this.groove, ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom))));
			this.groove.Elements.AddRange(new Prodige.Drawing.Element[] {
																			this.grooveBackground,
																			this.grooveBackgroundShadow,
																			this.grooveBackgroundShine,
																			this.grooveShadow,
																			this.grooveTopShadow,
																			this.grooveShine});
			// 
			// grooveKnob
			// 
			this.SetAnchor(this.grooveKnob, ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
				| System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right))));
			this.grooveKnob.Elements.AddRange(new Prodige.Drawing.Element[] {
																				this.groove,
																				this.knob});
			// 
			// TransparentSlider
			// 
			this.Elements.AddRange(new Prodige.Drawing.Element[] {
																	 this.backRectangle,
																	 this.ticks,
																	 this.grooveKnob});
			linearGradientFill3.Angle = 90F;
			linearGradientFill3.EndColor = System.Drawing.Color.FromArgb(((System.Byte)(122)), ((System.Byte)(91)), ((System.Byte)(89)), ((System.Byte)(132)));
			linearGradientFill3.EndOpacity = 0.4784314F;
			linearGradientFill3.StartColor = System.Drawing.Color.FromArgb(((System.Byte)(162)), ((System.Byte)(192)), ((System.Byte)(192)), ((System.Byte)(255)));
			linearGradientFill3.StartOpacity = 0.6352941F;
			linearGradientFill4.Angle = 90F;
			linearGradientFill4.EndColor = System.Drawing.Color.FromArgb(((System.Byte)(160)), ((System.Byte)(196)), ((System.Byte)(196)), ((System.Byte)(255)));
			linearGradientFill4.EndOpacity = 0.627451F;
			linearGradientFill4.BlendFocus = 0.05F;
			linearGradientFill4.StartOpacity = 0F;
			linearGradientFill5.Angle = 90F;
			linearGradientFill5.EndColor = System.Drawing.Color.FromArgb(((System.Byte)(0)), ((System.Byte)(255)), ((System.Byte)(255)), ((System.Byte)(255)));
			linearGradientFill5.EndOpacity = 0F;
			linearGradientFill5.StartColor = System.Drawing.Color.FromArgb(((System.Byte)(95)), ((System.Byte)(255)), ((System.Byte)(255)), ((System.Byte)(255)));
			linearGradientFill5.StartOpacity = 0.372549F;
			linearGradientFill6.Angle = 180F;
			linearGradientFill6.EndOpacity = 0F;
			linearGradientFill6.StartColor = System.Drawing.Color.FromArgb(((System.Byte)(217)), ((System.Byte)(196)), ((System.Byte)(196)), ((System.Byte)(255)));
			linearGradientFill6.StartOpacity = 0.8509804F;
			linearGradientFill7.Angle = 90F;
			linearGradientFill7.EndColor = System.Drawing.Color.FromArgb(((System.Byte)(171)), ((System.Byte)(0)), ((System.Byte)(0)), ((System.Byte)(255)));
			linearGradientFill7.EndOpacity = 0.6705883F;
			linearGradientFill7.StartColor = System.Drawing.Color.FromArgb(((System.Byte)(44)), ((System.Byte)(0)), ((System.Byte)(0)), ((System.Byte)(192)));
			linearGradientFill7.StartOpacity = 0.172549F;
			linearGradientFill8.Angle = 270F;
			linearGradientFill8.EndColor = System.Drawing.Color.FromArgb(((System.Byte)(82)), ((System.Byte)(128)), ((System.Byte)(128)), ((System.Byte)(255)));
			linearGradientFill8.EndOpacity = 0.3215686F;
			linearGradientFill8.StartColor = System.Drawing.Color.FromArgb(((System.Byte)(181)), ((System.Byte)(128)), ((System.Byte)(128)), ((System.Byte)(255)));
			linearGradientFill8.StartOpacity = 0.7098039F;
			stroke1.EndCap = System.Drawing.Drawing2D.LineCap.Round;
			stroke1.StartCap = System.Drawing.Drawing2D.LineCap.Round;
			stroke1.Width = 2F;
			linearGradientFill9.Angle = 0F;
			linearGradientFill9.EndColor = System.Drawing.Color.FromArgb(((System.Byte)(188)), ((System.Byte)(58)), ((System.Byte)(60)), ((System.Byte)(90)));
			linearGradientFill9.EndOpacity = 0.7372549F;
			linearGradientFill9.StartColor = System.Drawing.Color.FromArgb(((System.Byte)(192)), ((System.Byte)(135)), ((System.Byte)(136)), ((System.Byte)(192)));
			linearGradientFill9.StartOpacity = 0.7529412F;
			linearGradientFill10.BlendFactors.AddRange(new Prodige.Drawing.Styles.BlendFactor[] {
																									new Prodige.Drawing.Styles.BlendFactor(0F, 0F),
																									new Prodige.Drawing.Styles.BlendFactor(0.095F, 0F),
																									new Prodige.Drawing.Styles.BlendFactor(1F, 1F)});
			linearGradientFill10.EndColor = System.Drawing.Color.FromArgb(((System.Byte)(192)), ((System.Byte)(135)), ((System.Byte)(136)), ((System.Byte)(192)));
			linearGradientFill10.EndOpacity = 0.7529412F;
			linearGradientFill10.StartColor = System.Drawing.Color.FromArgb(((System.Byte)(0)), ((System.Byte)(0)), ((System.Byte)(0)));
			linearGradientFill11.Angle = 90F;
			linearGradientFill11.BlendFactors.AddRange(new Prodige.Drawing.Styles.BlendFactor[] {
																									new Prodige.Drawing.Styles.BlendFactor(0F, 0F),
																									new Prodige.Drawing.Styles.BlendFactor(0.483F, 1F),
																									new Prodige.Drawing.Styles.BlendFactor(1F, 1F)});
			linearGradientFill11.EndOpacity = 0F;
			linearGradientFill11.StartColor = System.Drawing.Color.FromArgb(((System.Byte)(0)), ((System.Byte)(0)), ((System.Byte)(0)));
			linearGradientFill12.Angle = 270F;
			linearGradientFill12.BlendFactors.AddRange(new Prodige.Drawing.Styles.BlendFactor[] {
																									new Prodige.Drawing.Styles.BlendFactor(0F, 0F),
																									new Prodige.Drawing.Styles.BlendFactor(0.483F, 1F),
																									new Prodige.Drawing.Styles.BlendFactor(1F, 1F)});
			linearGradientFill12.EndOpacity = 0F;
			linearGradientFill12.StartColor = System.Drawing.Color.FromArgb(((System.Byte)(97)), ((System.Byte)(177)), ((System.Byte)(180)), ((System.Byte)(248)));
			linearGradientFill12.StartOpacity = 0.3803922F;
			linearGradientFill13.Angle = 0F;
			linearGradientFill13.EndColor = System.Drawing.Color.FromArgb(((System.Byte)(194)), ((System.Byte)(39)), ((System.Byte)(35)), ((System.Byte)(120)));
			linearGradientFill13.EndOpacity = 0.7607843F;
			linearGradientFill13.StartColor = System.Drawing.Color.FromArgb(((System.Byte)(194)), ((System.Byte)(140)), ((System.Byte)(135)), ((System.Byte)(211)));
			linearGradientFill13.StartOpacity = 0.7607843F;
			linearGradientFill14.BlendFactors.AddRange(new Prodige.Drawing.Styles.BlendFactor[] {
																									new Prodige.Drawing.Styles.BlendFactor(0F, 0F),
																									new Prodige.Drawing.Styles.BlendFactor(0.095F, 0F),
																									new Prodige.Drawing.Styles.BlendFactor(1F, 1F)});
			linearGradientFill14.EndColor = System.Drawing.Color.FromArgb(((System.Byte)(194)), ((System.Byte)(140)), ((System.Byte)(135)), ((System.Byte)(211)));
			linearGradientFill14.EndOpacity = 0.7607843F;
			linearGradientFill14.StartColor = System.Drawing.Color.FromArgb(((System.Byte)(0)), ((System.Byte)(0)), ((System.Byte)(0)));
			this.Styles.Add(new Prodige.Drawing.Styles.Style("Background", null, linearGradientFill3, null, null));
			this.Styles.Add(new Prodige.Drawing.Styles.Style("Highlight", null, linearGradientFill4, null, null));
			this.Styles.Add(new Prodige.Drawing.Styles.Style("Shine", null, linearGradientFill5, null, null));
			this.Styles.Add(new Prodige.Drawing.Styles.Style("Groove", null, linearGradientFill6, null, null));
			this.Styles.Add(new Prodige.Drawing.Styles.Style("HoverBackground", null, linearGradientFill7, null, null));
			this.Styles.Add(new Prodige.Drawing.Styles.Style("DownBackground", null, linearGradientFill8, null, null));
			this.Styles.Add(new Prodige.Drawing.Styles.Style("Tick", stroke1, null, null, null));
			this.Styles.Add(new Prodige.Drawing.Styles.Style("GrooveBackground", null, linearGradientFill9, null, null));
			this.Styles.Add(new Prodige.Drawing.Styles.Style("GrooveShadow", null, linearGradientFill10, null, null));
			this.Styles.Add(new Prodige.Drawing.Styles.Style("GrooveTopShadow", null, linearGradientFill11, null, null));
			this.Styles.Add(new Prodige.Drawing.Styles.Style("GrooveShine", null, linearGradientFill12, null, null));
			this.Styles.Add(new Prodige.Drawing.Styles.Style("HoverGrooveBackground", null, linearGradientFill13, null, null));
			this.Styles.Add(new Prodige.Drawing.Styles.Style("HoverGrooveShadow", null, linearGradientFill14, null, null));
			textAppearance1.RenderingHint = System.Drawing.Text.TextRenderingHint.AntiAliasGridFit;
			textAppearance1.Size = 27F;
			textAppearance1.SizeUnit = System.Drawing.GraphicsUnit.World;
			this.TextAppearance = textAppearance1;
			this.MouseMove += new Prodige.Drawing.ElementMouseEventHandler(this.TransparentSlider_MouseMove);
			this.MouseEnter += new Prodige.Drawing.InputEventHandler(this.TransparentSlider_MouseEnter);
			this.MouseLeave += new Prodige.Drawing.InputEventHandler(this.TransparentSlider_MouseLeave);
			this.MouseUp += new Prodige.Drawing.ElementMouseEventHandler(this.TransparentSlider_MouseUp);
			this.MouseDown += new Prodige.Drawing.ElementMouseEventHandler(this.TransparentSlider_MouseDown);
			((System.ComponentModel.ISupportInitialize)(this)).EndInit();

		}
		#endregion
	}
}
