// Copyright  2007 Prodige Software Corporation. All rights reserved.
//#define LOG
using System;
using System.ComponentModel;
using System.Collections;
using System.Diagnostics;
using System.Windows.Forms;
using Prodige.Drawing;
using Prodige.Drawing.Styles;

namespace Prodige.Drawing
{
	/// <summary>
	/// Base class for a Picture that resizes without scaling, and 
	/// provides declarative layout properties to child elements.
	/// </summary>
	/// <remarks>
	/// This class is fairly primitive. It does not account for changes to the Picture,
	/// when Elements are added, removed, or modified. This may be the correct behavior
	/// -- the user may wish to preserve any initial padding and sizes.
	/// </remarks>
	[ProvideProperty("Anchor", typeof(Element))]
	[ProvideProperty("MinimumSize", typeof(Element))]
	public class UIElement : Picture, IExtenderProvider
	{
		// -------- static members --------
		private static readonly FSize defaultMinimum = new FSize(0, 0);

		// -------- instance members --------
		/// <summary>Stores layout information for each Element.</summary>
		private Hashtable properties;
		/// <summary>Indicates padding and reference sizes have been computed.
		/// </summary>
		private bool initialized;
		/// <summary>The initial size of the Picture, before resized.</summary>
		private FSize initialSize;
		/// <summary>The minimum size as specified by the user.</summary>
		private FSize minimumSize;
		/// <summary>
		/// The true minimum size, accounting for all movement and resizing of Elements.
		/// </summary>
		private FSize trueMinimum;
		/// <summary>The current bounds, as reported in GetBoundsCore.</summary>
		private FRectangle current;
		private bool fixedWidth;
		private bool fixedHeight;

		public UIElement() {}

		/// <summary>
		/// The minimum size of this UIElement, in Picture child coordinates.
		/// Override this property to dynamically compute the minumum size during
		/// SetBoundsCore calls.
		/// </summary>
		[Category("Layout")]
		[Description("The minimum size of this UIElement.")]
		public virtual FSize MinimumSize
		{
			get { return minimumSize; }
			set { minimumSize = value; }
		}

		private bool ShouldSerializeMinimumSize()
		{
			return !minimumSize.IsEmpty;
		}

		private void ResetMinimumSize()
		{
			minimumSize = FSize.Empty;
		}

		protected override bool SetBoundsCore(FRectangle bounds, BoundsChanges changes)
		{
			if (!initialized)
			{
				//	determine reference size and min bounds (done once only)
				current = Bounds;
				InitializeReferenceSize(this, this, minimumSize, out initialSize,
					out fixedWidth, out fixedHeight, out trueMinimum);
				initialized = true;
			}
			//	move and resize elements
			current = SetBounds(this, this, bounds, current, initialSize, trueMinimum, 
				fixedWidth, fixedHeight);
			return true;
		}

		private static FRectangle SetBounds(UIElement root, Composite composite, FRectangle requested,
			FRectangle current, FSize initialSize, FSize trueMinimum, 
			bool fixedWidth, bool fixedHeight)
		{
			Log("");
			Log("Current: " + current);
			Log("Requested: " + requested);
			requested = ConstrainedBounds(requested, initialSize, trueMinimum, fixedWidth, fixedHeight);
			if (requested == current)
				return current;
			Log("Constrained requested: " + requested);

			// first resize anchored items
			FRectangle newBounds = new FRectangle(current.Location, requested.Size);
			ResizeAnchored(root, composite, newBounds, initialSize);
			// move all children
			Vector offset = requested.Location - current.Location;
			Log("Offset: " + offset);
			foreach (Element e in composite.Elements)
				e.ChangeRelativeLocation(offset, root);
			return requested;
		}

		private static FRectangle ConstrainedBounds(FRectangle bounds, FSize initialSize,
			FSize trueMinimum, bool fixedWidth, bool fixedHeight)
		{
			if (bounds.Width < trueMinimum.Width)
				bounds.Width = trueMinimum.Width;
			if (bounds.Height < trueMinimum.Height)
				bounds.Height = trueMinimum.Height;
			if (fixedWidth)
				bounds.Width = initialSize.Width;
			if (fixedHeight)
				bounds.Height = initialSize.Height;
			return bounds;
		}

		protected override FRectangle GetBoundsCore()
		{
			return initialized ? current : base.GetBoundsCore();
		}

		private static void ResizeAnchored(UIElement root, Composite composite,
			FRectangle reference, FSize initialSize)
		{
			foreach (Element e in composite.Elements)
			{
				LayoutInfo info = root.GetInfo(e);
				Log(e.Name + " ------------");
				if (info == null || info.Anchor == (AnchorStyles.Top | AnchorStyles.Left))
					continue;
				FRectangle old = e.GetRelativeBounds(root);
				FRectangle newBounds = ComputeAnchoredBounds(info, old, reference, initialSize);
				if (newBounds != old)
				{
					Log("  old: " + old);
					Log("  requested: " + newBounds);
					Group group = e as Group;
					if (group != null)
					{
						GroupInfo groupInfo = (GroupInfo)info;
						SetBounds(root, group, newBounds, old, groupInfo.InitialSize, 
							groupInfo.TrueMinimum, groupInfo.FixedWidth, groupInfo.FixedHeight);
					}
					else
						e.SetRelativeBounds(newBounds, root);
					Log("  new: " + e.GetRelativeBounds(root));
				}
			}
		}

		private static FRectangle ComputeAnchoredBounds(
			LayoutInfo info, FRectangle old, FRectangle reference, FSize initialSize)
		{
			float l = old.Left;
			float t = old.Top;
			float r = old.Right;
			float b = old.Bottom;

			if (info.AnchorLeft)
			{
				l = reference.Left + info.Left;
				r = l + old.Width;
				Log("change left: " + l + " right: " + r);
			}
			if (info.AnchorRight)
			{
				r = reference.Right - info.Right;
				if (!info.AnchorLeft)
					l = r - old.Width;
				Log("change right: " + r + " left: " + l);
			}
			if (!info.AnchorLeft && !info.AnchorRight)
				InterpolateCenter(ref l, ref r, initialSize.Width, reference.Left, reference.Width, info.Left);
			SwapIfLess(ref r, ref l);
			if (info.AnchorTop)
			{
				t = reference.Top + info.Top;
				b = t + old.Height;
			}
			if (info.AnchorBottom)
			{
				b = reference.Bottom - info.Bottom;
				if (!info.AnchorTop)
					t = b - old.Height;
			}
			if (!info.AnchorTop && !info.AnchorBottom)
				InterpolateCenter(ref t, ref b, initialSize.Height, reference.Top, reference.Height, info.Top);
			SwapIfLess(ref b, ref t);
			return new FRectangle(new Vector(l, t), new Vector(r, b));
		}

		private static void InterpolateCenter(ref float begin, ref float end, float initialSpan, 
			float referenceBegin, float referenceSpan, float padding)
		{
			// move center
			float span = end - begin;
			// fraction of begin along original span
			float delta;
			if (initialSpan <= span)
				delta = 0;
			else
				delta = padding / (initialSpan - span);
			float newSpan = referenceSpan - span;
			begin = referenceBegin + delta * newSpan;
			end = begin + span;
		}

		private static void SwapIfLess(ref float a, ref float b)
		{
			if (a < b)
			{
				float tmp = b;
				b = a;
				a = tmp;
			}
		}

		private static void InitializeReferenceSize(UIElement root,
			Composite composite, FSize minimumSize,
			out FSize initialSize, out bool fixedWidth, out bool fixedHeight,
			out FSize trueMinimum)
		{
			FRectangle reference;
			if (composite == root)
				reference = root.Bounds;
			else
				reference = composite.GetRelativeBounds(root);
			initialSize = reference.Size;
			// all bounds are computed in picture child coords 
			// first record padding and descend to Groups recursively
			foreach (Element e in composite.Elements)
			{
				LayoutInfo li = root.GetOrCreateInfo(e);
				InitializePadding(root, e, li, reference);
				Group group = e as Group;
				if (group != null)
				{
					// recurse on Group
					GroupInfo gi = (GroupInfo)li;
					FSize tm;
					InitializeReferenceSize(root, group, gi.Minimum,
						out gi.InitialSize, out gi.FixedWidth, out gi.FixedHeight, out tm);
					gi.TrueMinimum = tm;
				}
			}

			fixedWidth = true;
			fixedHeight = true;
			FRectangle minBounds = new FRectangle();
			bool firstX = true;
			bool firstY = true;
			// compute trueMinimum
			trueMinimum = minimumSize;
			foreach (Element e in composite.Elements)
			{

				LayoutInfo li = root.GetInfo(e);
				FRectangle eb = e.GetRelativeBounds(root);
				if (eb.Width == 0 && eb.Height == 0)
					continue;
				// compute minimal bounds
				float minWidth = eb.Width;
				float minHeight = eb.Height;
				
				if (li.AnchorRight && li.AnchorLeft)
					minWidth = li.Left + li.TrueMinimum.Width + li.Right;
				else if (li.AnchorLeft)
					minWidth += li.Left;
				else if (li.AnchorRight)
					minWidth += li.Right;

				if (li.AnchorTop && li.AnchorBottom)
					minHeight = li.Top + li.TrueMinimum.Height + li.Bottom;
				else if (li.AnchorTop)
					minHeight += li.Top;
				else if (li.AnchorBottom)
					minHeight += li.Bottom;

				if (li.AnchorLeft || li.AnchorRight)
				{
					if (li.AnchorRight)
						fixedWidth = false;
					trueMinimum.Width = Math.Max(minWidth, trueMinimum.Width);
				}
				else
				{
					if (firstX)
					{
						minBounds.X = eb.Left;
						minBounds.Width = eb.Width;
						firstX = false;
					}
					else
					{
						float x1 = Math.Min(minBounds.Left, eb.Left);
						float x2 = Math.Max(minBounds.Right, eb.Right);
						minBounds.X = x1;
						minBounds.Width = x2 - x1;
					}
				}

				if (li.AnchorTop || li.AnchorBottom)
				{
					if (li.AnchorBottom)
						fixedHeight = false;
					trueMinimum.Height = Math.Max(minHeight, trueMinimum.Height);
				}
				else
				{
					if (firstY)
					{
						minBounds.Y = eb.Top;
						minBounds.Height = eb.Height;
						firstY = false;
					}
					else
					{
						float y1 = Math.Min(minBounds.Top, eb.Top);
						float y2 = Math.Max(minBounds.Bottom, eb.Bottom);
						minBounds.Y = y1;
						minBounds.Height = y2 - y1;
					}
				}
			}

			if (!firstX)
				trueMinimum.Width = Math.Max(minBounds.Width, trueMinimum.Width);
			if (!firstY)
				trueMinimum.Height = Math.Max(minBounds.Height, trueMinimum.Height);
		}

		private static void InitializePadding(Picture root, Element element, 
			LayoutInfo li, FRectangle reference)
		{
			if (li.PaddingInitialized)
				return;
			FRectangle eb = element.GetRelativeBounds(root);
			li.Left = eb.Left - reference.Left;
			li.Right = reference.Right - eb.Right;
			li.Top = eb.Top - reference.Top;
			li.Bottom = reference.Bottom - eb.Bottom;
			li.PaddingInitialized = true;
			Log(string.Format("Init: {0} left, top, right, bottom: ({1}, {2}) ({3}, {4})",
				element.Name, li.Left, li.Top, li.Right, li.Bottom));
		}

		[Conditional("LOG")]
		private static void Log(string s)
		{
			Debug.WriteLine(s);
		}

		bool IExtenderProvider.CanExtend(object extendee)
		{
			Element element = extendee as Element;
			return element != this && element.PictureParent == this;
		}

		[Category("Layout"), DefaultValue(AnchorStyles.Top | AnchorStyles.Left)]
		[Description("Forces the specified edge of the Element Bounds to maintain a fixed " +
			 "distance from the Picture Bounds edge.")]
		public AnchorStyles GetAnchor(Element element)
		{
			LayoutInfo li = GetInfo(element);
			if (li == null)
				return AnchorStyles.Top | AnchorStyles.Left;
			return li.Anchor;
		}

		public void SetAnchor(Element element, AnchorStyles value)
		{
			LayoutInfo li = GetOrCreateInfo(element);
			li.Anchor = value;
		}

		[Category("Layout")]
		[Description("Specifies the mimimum width and height of this Element, in the child coordinate " +
			 "space of the Picture parent.")]
		public FSize GetMinimumSize(Element element)
		{
			LayoutInfo li = GetInfo(element);
			if (li == null)
				return defaultMinimum;
			return li.Minimum;
		}

		public void SetMinimumSize(Element element, FSize value)
		{
			LayoutInfo li = GetOrCreateInfo(element);
			li.Minimum = value;
		}

		private bool ShouldSerializeMinimumSize(Element element)
		{
			LayoutInfo li = GetInfo(element);
			return li != null && (li.Minimum != defaultMinimum);
		}

		private void ResetMinimumSize(Element element)
		{
			LayoutInfo li = GetInfo(element);
			if (li == null)
				return;
			li.Minimum = defaultMinimum;
		}

		private LayoutInfo GetInfo(Element element)
		{
			if (properties == null)
				return null;
			return properties[element] as LayoutInfo;
		}

		private LayoutInfo GetOrCreateInfo(Element element)
		{
			LayoutInfo li = GetInfo(element);
			if (li == null)
			{
				if (properties == null)
					properties = new Hashtable();
				if (element is Group)
					li = new GroupInfo();
				else
					li = new LayoutInfo();
				properties[element] = li;
			}
			return li;
		}

		/// <summary>Layout information for each Element.</summary>
		private class LayoutInfo
		{
			/// <summary>The edges anchored on this Element.</summary>
			public AnchorStyles Anchor;
			/// <summary>The minimum size.</summary>
			public FSize Minimum;
			/// <summary>Indicates whether the padding is initialized.</summary>
			public bool PaddingInitialized;
			/// <summary>Left padding.</summary>
			public float Left;
			/// <summary>Top padding.</summary>
			public float Top;
			/// <summary>Right padding.</summary>
			public float Right;
			/// <summary>Bottom padding.</summary>
			public float Bottom;

			public LayoutInfo()
			{
				Anchor = AnchorStyles.Left | AnchorStyles.Top;
				Minimum = defaultMinimum;
			}

			public bool AnchorLeft
			{
				get { return (Anchor & AnchorStyles.Left) != 0; }
			}

			public bool AnchorRight
			{
				get { return (Anchor & AnchorStyles.Right) != 0; }
			}

			public bool AnchorTop
			{
				get { return (Anchor & AnchorStyles.Top) != 0; }
			}

			public bool AnchorBottom
			{
				get { return (Anchor & AnchorStyles.Bottom) != 0; }
			}

			public virtual FSize TrueMinimum
			{
				get { return Minimum; }
				set { throw new InvalidOperationException("Cannot set TrueMinimum"); }
			}
		}

		/// <summary>Layout information for each Group.</summary>
		private class GroupInfo : LayoutInfo
		{
			/// <summary>The initial size of the Group.</summary>
			public FSize InitialSize;
			/// <summary>The true minimum size, acounting for all movement from anchoring.
			/// </summary>
			private FSize trueMinimum;
			/// <summary>Indicates whether the width is fixed.</summary>
			public bool FixedWidth;
			/// <summary>Indicates whether the height is fixed.</summary>
			public bool FixedHeight;

			public GroupInfo() {}

			public override FSize TrueMinimum
			{
				get { return trueMinimum; }
				set { trueMinimum = value; }
			}
		}
	}

		//public enum PictureResizeAlgorithm
		//{
		//    Scale,
		//    Resize,
		//    ChangeAnchored
		//}

		//public enum GroupResizeAlgorithm
		//{
		//    Resize,
		//    ChangeAnchored
		//}
}
